@@ -1,4 +1,3 @@
-/* $Id$ */
 /*-
  * Copyright (c) 2004-2008 os-cillation e.K.
  *
@@ -234,8 +233,8 @@ static const GtkActionEntry action_entries[] =
   { "view-menu", NULL, N_ ("_View"), NULL, NULL, NULL, },
   { "terminal-menu", NULL, N_ ("_Terminal"), NULL, NULL, NULL, },
     { "set-title", NULL, N_ ("_Set Title..."), NULL, N_ ("Set a custom title for the current tab"), G_CALLBACK (terminal_window_action_set_title), },
-    { "reset", GTK_STOCK_REFRESH, N_ ("_Reset"), NULL, NULL, G_CALLBACK (terminal_window_action_reset), },
-    { "reset-and-clear", GTK_STOCK_CLEAR, N_ ("Reset and C_lear"), NULL, NULL, G_CALLBACK (terminal_window_action_reset_and_clear), },
+    { "reset", GTK_STOCK_REFRESH, N_ ("_Reset"), NULL, N_ ("Reset"), G_CALLBACK (terminal_window_action_reset), },
+    { "reset-and-clear", GTK_STOCK_CLEAR, N_ ("Reset and C_lear"), NULL, N_ ("Reset and clear"), G_CALLBACK (terminal_window_action_reset_and_clear), },
   { "go-menu", NULL, N_ ("_Go"), NULL, NULL, NULL, },
     { "prev-tab", GTK_STOCK_GO_BACK, N_ ("_Previous Tab"), NULL, N_ ("Switch to previous tab"), G_CALLBACK (terminal_window_action_prev_tab), },
     { "next-tab", GTK_STOCK_GO_FORWARD, N_ ("_Next Tab"), NULL, N_ ("Switch to next tab"), G_CALLBACK (terminal_window_action_next_tab), },
@@ -1528,7 +1527,7 @@ title_dialog_response (GtkWidget *dialog,
   if (response == GTK_RESPONSE_HELP)
     {
       /* open the "Set Title" paragraph in the "Usage" section */
-      terminal_dialogs_show_help (GTK_WIDGET (dialog), "usage", "set-title");
+      terminal_dialogs_show_help (GTK_WINDOW (dialog), "usage.html", "set-title");
     }
   else
     {
@@ -1620,7 +1619,7 @@ terminal_window_action_report_bug (GtkAction       *action,
                                    TerminalWindow  *window)
 {
   /* open the "Support" section of the user manual */
-  terminal_dialogs_show_help (GTK_WIDGET (window), "support", NULL);
+  terminal_dialogs_show_help (GTK_WINDOW (window), "support.html", NULL);
 }
 
 
@@ -1630,7 +1629,7 @@ terminal_window_action_contents (GtkAction       *action,
                                  TerminalWindow  *window)
 {
   /* open the Terminal user manual */
-  terminal_dialogs_show_help (GTK_WIDGET (window), NULL, NULL);
+  terminal_dialogs_show_help (GTK_WINDOW (window), NULL, NULL);
 }
 
 
@@ -1739,23 +1738,6 @@ terminal_window_add (TerminalWindow *window,
 
 
 
-/**
- * terminal_window_remove:
- * @window  : A #TerminalWindow.
- * @screen  : A #TerminalScreen.
- **/
-void
-terminal_window_remove (TerminalWindow *window,
-                        TerminalScreen *screen)
-{
-  terminal_return_if_fail (TERMINAL_IS_WINDOW (window));
-  terminal_return_if_fail (TERMINAL_IS_SCREEN (screen));
-
-  gtk_widget_destroy (GTK_WIDGET (screen));
-}
-
-
-
 /**
  * terminal_window_get_active:
  * @window : a #TerminalWindow.
